@@ -1,6 +1,10 @@
 import numpy as np
 import matplotlib.pyplot as plt
+
 from sklearn import svm
+import warnings
+warnings.filterwarnings("ignore")
+
 import uuid
 import scipy
 import pylab, matplotlib
